/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.model;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import net.sourceforge.cobertura.coveragedata.ClassData;

/**
 * Coverage of a class defined in a given source file (this nodes parent) and whose children
 * represent coverage of individual methods defined in this class.
 */

public class ClassDataPair extends CoverageDataPair<ClassData, SourceFileDataPair, MethodDataPair> {
	

	public ClassDataPair( ClassData data, ClassData samePackageData, SourceFileDataPair parent ) {
		super( data, samePackageData, parent );
		buildMethodDataHelpers();
	}

	void buildMethodDataHelpers() {
		List<MethodData> mds = new ArrayList<MethodData>();
		for( String mnd : getData().getMethodNamesAndDescriptors() ) {
			MethodData md = new MethodData( getData(), mnd);
			mds.add( md );
		}
		Collections.sort( mds );	
		for ( MethodData md : mds ) {
			MethodData dmcd = null;
			if ( getSamePackageData() != null ) {
				dmcd = new MethodData( getSamePackageData(), md.getName() );
			}
			addChild( getFactory().makeMethodDataPair( md, dmcd, this ));
		}
	}

	@Override
	public Comparable<?> getOrderingObject() {
		return getData().getName();
	}

}
