/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.model;

/**
 * Whether you prefer coverage in terms of lines, branches, or the sum of the two, 
 * this class presents the interesting totals and rates in a uniform way.
 * 
 * @see CoverageDataPair#getElementCounts()
 * @see CoverageDataPair#getLineCounts()
 * @see CoverageDataPair#getBranchCounts()
 */

public class CoverageSummaryView {

	int valid, covered, samePackageCovered;
	
	public int getValid() {
		return valid;
	}

	public int getCovered() {
		return covered;
	}

	public int getSamePackageCovered() {
		return samePackageCovered;
	}

	public CoverageSummaryView(int validCount, int coveredCount,
			int samePackageCoveredCount) {
		if (validCount < coveredCount) {
			throw new IllegalArgumentException(
					"coveredCount must not be greater than validCount, not "
							+ coveredCount + " v. " + validCount);
		}
		if ( coveredCount < samePackageCoveredCount ) {
			throw new IllegalArgumentException(
					"samePackageCoveredCount must not be greater than coveredCount, not "
							+ samePackageCoveredCount + " v. " + coveredCount);
		}
		this.valid = validCount;
		this.covered = coveredCount;
		this.samePackageCovered = samePackageCoveredCount;
	}

	public int getMissed() {
		return getValid() - getCovered();
	}
	
	public int getSamePackageMissed() {
		return getValid() - getSamePackageCovered();
	}
	
	public double getRate( ) {
		if ( getValid() == 0 ) {
			return Double.NaN;
		}
		else {
			return getCovered() / (double) getValid();
		}
	}

	public double getSamePackageRate( ) {
		if ( getValid() == 0 ) {
			return Double.NaN;
		}
		else {
			return getSamePackageCovered() / (double) getValid();
		}
	}
	
	public boolean getAllCovered() {
		return getValid() == getCovered();
	}
	
	public boolean getAllSamePackageCovered() {
		return getValid() == getSamePackageCovered();
	}
	
	public String toString() {
		return "N: " + getValid() + " all: " + getMissed() + " pkg: " + getSamePackageMissed();
	}
}
