/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.model;

import net.sourceforge.cobertura.coveragedata.LineData;

/**
 * Coverage of a given method.
 * 
 * Methods are most naturally ordered by their first line number, which is
 * returned by {@link #getOrderingObject()}. Note, however, that the
 * constructors, <init> and <clinit> methods of classes may overlap. The
 * {@link #getDisplayName()} is a bit cryptic.
 */
public class MethodDataPair extends CoverageDataPair<MethodData, ClassDataPair, LineDataPair> {

	public MethodDataPair( MethodData data, MethodData samePackageData, ClassDataPair parent ) {
		super( data, samePackageData, parent );
		buildLineDataHelpers();
	}

	void buildLineDataHelpers() {
		for (LineData ld : getData().getLines()) {
			LineData dld = null;
			if (getParent().getSamePackageData() != null) {
				dld = getParent().getSamePackageData().getLineCoverage(
						ld.getLineNumber());
			}
			addChild( getFactory().makeLineDataPair(ld, dld, this));
		}
	}

	@Override
	public Comparable<?> getOrderingObject() {
		return getData().getFirstAndLastLinesForMethod()[0];
	}
	
	@Override
	public Object getName() {
		return getData().getName();
	}
	
	@Override
	public String getDisplayName() {
		return getData().getName();
	}

}
