/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.model;

import java.util.Map;

import net.sourceforge.cobertura.coveragedata.PackageData;
import net.sourceforge.cobertura.coveragedata.ProjectData;

/**
 * Root node of a coverage tree. {@link #getParent()} return null, and children
 * of {@link PackageDataPair}. The notion {@link #getSamePackageData()} makes no
 * sense here; the return value of that method will be null.
 */

public class ProjectDataPair extends CoverageDataPair<ProjectData, ProjectDataPair, PackageDataPair> {
	
	public ProjectDataPair( ProjectData data, Map<String, ProjectData> packageToCoverage ) {
		this( data, packageToCoverage, new CoverageDataPairFactory() );
	}

	ProjectDataPair( ProjectData data, Map<String, ProjectData> packageToCoverage, CoverageDataPairFactory factory ) {
		super( data, null, null );
		coverageDataPairFactory = factory;
		this.data = data;
		buildPackageDataHelpers( packageToCoverage);
	}

	void buildPackageDataHelpers(Map<String, ProjectData> packageToCoverage ) {
		for( Object o : data.getPackages() ) {
			PackageData pd = (PackageData) o;
			PackageData dpd = null;
			ProjectData samePackageData = packageToCoverage.get( pd.getName() );
			if ( samePackageData != null ) {
				dpd = (PackageData) samePackageData.getChild( pd.getName() );
			}
			try {
				PackageDataPair pdp = getFactory().makePackageDataPair( pd, dpd, this );
				addChild( pdp );
			}
			catch( RuntimeException e ) {
				throw new RuntimeException( "Could not create PackageDataPair " + pd.getName(), e );
			}
		}
	}
	
	@Override
	public ProjectDataPair getRoot() {
		return this;
	}

	@Override
	public Comparable<?> getOrderingObject() {
		return "-All-";
	}
	
	CoverageDataPairFactory coverageDataPairFactory;
	
	CoverageDataPairFactory getFactory() {
		return coverageDataPairFactory;
	}

}
