/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.model;

import java.util.HashMap;
import java.util.Map;

import net.sourceforge.cobertura.coveragedata.ClassData;
import net.sourceforge.cobertura.coveragedata.SourceFileData;

/**
 * Parent is coverage of a package, child is coverage of a class (including
 * inner classes) contained in this source file.
 */

public class SourceFileDataPair extends CoverageDataPair<SourceFileData, PackageDataPair, ClassDataPair> {
	
	Map<Integer,Object[]> keyForLine = new HashMap<Integer, Object[]>();

	public SourceFileDataPair( SourceFileData data, SourceFileData samePackageData, PackageDataPair parent ) {
		super( data, samePackageData, parent );
		buildClassDataHelpers();
		buildKeyForLine();
	}

	void buildClassDataHelpers() {
		for( Object o : getData().getClasses() ) {
			ClassData cd = (ClassData) o;
			ClassData dcd = null;
			if ( getSamePackageData() != null ) {
				dcd = (ClassData) getSamePackageData().getChild( cd.getBaseName() );
			}
			try {
				ClassDataPair cdp = getFactory().makeClassDataPair( cd, dcd, this );
				addChild( cdp );
			}
			catch( RuntimeException e ) {
				throw new RuntimeException( "Could not create ClassDataPair " + cd.getName(), e );
			}
		}
	}
	
	void buildKeyForLine() {
		for( Object[] key : getGreatGrandchildKeys() ) {
			keyForLine.put( (Integer) key[2], key );
		}
	}

	@Override
	public Comparable<?> getOrderingObject() {
		return getData().getBaseName();
	}

	public LineDataPair getLine(int lineNumber) {
		return (LineDataPair) getVanillaDescendent( keyForLine.get( lineNumber ));
	}

}
