/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.parsing;

import java.util.ArrayList;
import java.util.List;

import net.sourceforge.purrpackage.model.ProjectDataPair;

/** 
 * Convenient view of the this packages computations.
 */
public class PerPackageCoverageRunSummary {
	
	boolean errorFree = true;
	ProjectDataPair data;
	List<String> filesRead = new ArrayList<String>();
	List<String> readerErrors = new ArrayList<String>();
	List<String> calculatorErrors = new ArrayList<String>();
	
	public PerPackageCoverageRunSummary(ProjectDataPair pdp,
			CoverageDirectoryReader cdr, PackageCoverageCalculator calc) {
		data = pdp;
		if (cdr != null) {
			filesRead.addAll(cdr.getLoadedFiles());
			for (String s : cdr.getUnloadableFiles().keySet()) {
				readerErrors.add("Failed to read file " + s + ": "
						+ cdr.getUnloadableFiles().get(s));
				errorFree = false;
			}
		} else {
			errorFree = false;
		}
		if (calc != null) {
			if (!calc.isErrorFree()) {
				errorFree = false;
				int i = 0;
				for (ProjectDataDifferenceCalculator diff : calc.getDiffs()) {
					for (String s : diff.getErrors()) {
						calculatorErrors.add("At " + i + ": " + s);
					}
					++i;
				}

			}
		} else {
			errorFree = false;
		}
		if (data == null) {
			errorFree = false;
		}
	}

	public boolean isErrorFree() {
		return errorFree;
	}

	public ProjectDataPair getData() {
		return data;
	}

	public List<String> getFilesRead() {
		return filesRead;
	}

	public List<String> getReaderErrors() {
		return readerErrors;
	}

	public List<String> getCalculatorErrors() {
		return calculatorErrors;
	}
	

}
