/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

package net.sourceforge.purrpackage.recording;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * Uses a properties file "purrpackage.db" to track the last package that was
 * run. Enables coverage runs that span multiple VMs in sequence.
 */

public class PropDb {

	static final String CURRENT_PACKAGE = "currentPackage";
	static final String COUNT = "count";
	public static final String FILE_NAME = "purrpackage.db";

	Integer count;
	String packageName;

	Properties makeProperties() {
		return new Properties();
	}

	public void read(File directory) throws IOException {
		File f = new File(directory, FILE_NAME);
		if (f.exists()) {
			Properties p = makeProperties();
			FileInputStream fis = new FileInputStream(new File(directory,
					FILE_NAME));
			try {
				p.load(fis);
			} finally {
				fis.close();
			}
			packageName = p.getProperty(CURRENT_PACKAGE);
			String s = p.getProperty(COUNT);
			try {
				count = new Integer(s);
			} catch (Exception e) {
				throw new RuntimeException(FILE_NAME
						+ " corrupt: could not read count from (" + s + ")");
			}
		}
	}

	static final String PROP_FILE_COMMENT = "Used by purrpackage coverage recorder to track state across vm runs";
	
	public void write(File directory) throws IOException {
		Properties p = makeProperties();
		p.setProperty(COUNT, String.valueOf(count));
		p.setProperty(CURRENT_PACKAGE, packageName);
		FileOutputStream fos = new FileOutputStream(new File(directory,
				FILE_NAME));
		try {
			p.store( fos, PROP_FILE_COMMENT );
		} finally {
			fos.close();
		}
	}

	public Integer getCount() {
		return count;
	}

	public void setCount(Integer count) {
		this.count = count;
	}

	public String getPackageName() {
		return packageName;
	}

	public void setPackageName(String packageName) {
		this.packageName = packageName;
	}

}
