/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.reporting;
import java.io.File;
import java.util.Collection;

import org.mozilla.javascript.Context;
import org.mozilla.javascript.Scriptable;
import org.mozilla.javascript.tools.shell.Global;
import org.mozilla.javascript.tools.shell.Main;


public class BuildTimeJavascriptReporter {

	static volatile boolean inited = false;

	synchronized void init() {
		if ( ! inited ) {
			Context c = Context.enter();
			c.setOptimizationLevel( -1 );
			Global g = Main.getGlobal();
			g.init( c );
			inited = true;
		}
	}
	
	File baseDir;
	File sourceFile;
	Collection<String> errorHolder;

	public BuildTimeJavascriptReporter( File baseDir, File sourceFile, Collection<String> errorHolder ) throws Exception {
		this.baseDir = baseDir;
		this.sourceFile = sourceFile;
		this.errorHolder = errorHolder;			
		init();
	}

	public void report() {
		Context c = Context.enter();
		Scriptable scope = Main.getGlobal();
		try {
			runInitScripts( c, scope );
		}
		catch( Exception e ) {
			throw new RuntimeException( "Failed to read or initialize buildTimeReportSupport.js", e );
		}
		try {
			File policy = new File( baseDir, "jsonCoverageData/coveragePolicy.js" );
			if ( policy.exists() ) {
				runPolicyMethod(c, scope);
			}
		}
		catch( Exception e ) {
			errorHolder.add( "Failed to apply coverage policy: " + e.getMessage() );
		}
		try {
			runUserScript( c );
		}
		catch( Exception e ) {
			errorHolder.add( "Failed to run report script: " + e.getMessage() );
		}
		Context.exit();
	}
	
	void runInitScripts(Context c, Scriptable scope) {
		Main.processSource(c, new File(baseDir,
				"standard/generalJs/env.rhino.1.2.js").getAbsolutePath());
		Main.processSource(c, new File( baseDir, 
				"standard/generalJs/Util.js" ).getAbsolutePath() ); // gzip util
		c.evaluateString(scope, "window.location='file://"
				+ baseDir.getAbsolutePath() + "/';", this
				.getClass().getName(), 1, null);
		Main.processSource(c, new File(baseDir,
				"standard/generalJs/buildTimeReportSupport.js")
				.getAbsolutePath());
	}
	
	void runPolicyMethod( Context c, Scriptable scope ) {		
		c.evaluateString( scope, "buildTimeReportSupport.readAndApplyPolicy()", this.getClass().getName(), 2, null );
	}

	void runUserScript( Context c ) {
		Main.processSource(c, sourceFile.getAbsolutePath());
	}

}
