/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.reporting;

import java.io.File;
import java.io.IOException;

import net.sourceforge.purrpackage.recording.Copier;


/**
 * Some utilities for managing files.
 */

public class FileHelper extends Copier {

	/**
	 * A bit whacky. Looks for a file at path or a file with the defaultFileName
	 * in the path directory. If found, copies to destdir under the
	 * defaultFileName. otherwise does nothing.
	 */
	public void copyFileOrFileInDirectoryIfExists(String path,
			String defaultFileName, File destdir) throws IOException {
		if (!isPathPossiblyValid(path)) {
			return;
		}
		File x = new File(path);
		if (x.exists()) {
			if (x.isDirectory()) {
				x = new File(x, defaultFileName);
			}
			if (x.exists()) {
				copyFile(x, new File(destdir, defaultFileName));
			}
		}
	}
	
	/** Trivial test of a proposed path */
	boolean isPathPossiblyValid( String path ) {
		return path != null && path.trim().length() > 0;
	}	

	/**
	 * Recursively removes a directory or file. On failure, the exception
	 * names the file that could not be removed.
	 */
	public void rmRec( File x ) throws IOException {
		if ( x.isDirectory() ) {
			for( File f : x.listFiles() ) {
				rmRec( f );
			}
		}
		if ( !x.delete() ) {
			throw new IOException( "Failed to delete file at " + x.getCanonicalPath() );
		}
	}

}
