/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

package net.sourceforge.purrpackage.reporting;

import java.io.File;

import net.sourceforge.cobertura.coveragedata.ProjectData;
import net.sourceforge.cobertura.reporting.ComplexityCalculator;
import net.sourceforge.cobertura.util.FileFinder;
import net.sourceforge.purrpackage.model.ProjectDataPair;
import net.sourceforge.purrpackage.parsing.CoverageDirectoryReader;
import net.sourceforge.purrpackage.parsing.PackageCoverageCalculator;

public class ReportSupport {

	public ReportSupport() {
		
	}
	
	CoverageDirectoryReader coverageDirectoryReader;
	PackageCoverageCalculator calculator;
	ProjectDataPair data;
	File coverageDataFile = null;
	File destinationDir = null;
	String coveragePolicyPath = null;
	String buildTimeReportScriptPath = null;


	String encoding = "UTF8";

	FileFinder finder = new FileFinder();
	ComplexityCalculator complexity = new ComplexityCalculator(finder);
	
	// Set all value before calling, please.
	public void readAndParseCoverageData() throws Exception {
		CoverageDirectoryReader cdr = new CoverageDirectoryReader();
		cdr.loadDirectory(coverageDataFile.getParentFile());
		coverageDirectoryReader = cdr;
		calculator = new PackageCoverageCalculator(cdr.getIndexedPackageData()
				.values());

		ProjectData projectData = getGlobalData();

		if (projectData == null) {
			throw new RuntimeException( "Unable to read coverage data from file "
					+ coverageDataFile.getCanonicalPath());
		}

		data = new ProjectDataPair(projectData, calculator.getPackageToCoverage());
	}
	
	ProjectData getGlobalData() {
		return coverageDirectoryReader.getGlobalCoverageData();
	}

	public void addSourceDirectory( String path ) {
		finder.addSourceDirectory( path );
	}
	
	public void setCoverageDataFile(File coverageDataFile) {
		this.coverageDataFile = coverageDataFile;
	}

	public void setDestinationDir(File destinationDir) {
		this.destinationDir = destinationDir;
	}

	public void setCoveragePolicyPath(String coveragePolicyPath) {
		this.coveragePolicyPath = coveragePolicyPath;
	}

	public void setBuildTimeReportScriptPath(String buildTimeReportScriptPath) {
		this.buildTimeReportScriptPath = buildTimeReportScriptPath;
	}
	
	public String getBuildTimeReportScriptPath() {
		return buildTimeReportScriptPath;
	}

	public CoverageDirectoryReader getCoverageDirectoryReader() {
		return coverageDirectoryReader;
	}

	public PackageCoverageCalculator getCalculator() {
		return calculator;
	}

	public ProjectDataPair getData() {
		return data;
	}

	public File getCoverageDataFile() {
		return coverageDataFile;
	}

	public File getDestinationDir() {
		return destinationDir;
	}

	public String getCoveragePolicyPath() {
		return coveragePolicyPath;
	}

	public FileFinder getFinder() {
		return finder;
	}

	public ComplexityCalculator getComplexity() {
		return complexity;
	}

	public String getEncoding() {
		return encoding;
	}

	public void setEncoding(String encoding) {
		this.encoding = encoding;
	}

}
