/*
 * Purrpackage - http://purrpackage.sourceforge.net
 * Copyright (C) 2010 John Charles Roth
 *
 * Purrpackage is free software, licensed under the terms of the GNU GPL 
 * Version 2 or, at your option, any later version. You should have 
 * received a copy of the license with this file. See the above web address
 * for more information, or contact the Free Software Foundation, Boston, MA. 
 * It is distributed WITHOUT WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package net.sourceforge.purrpackage.reporting.json;

import java.util.ArrayList;
import java.util.Collection;

import net.sourceforge.cobertura.coveragedata.JumpData;
import net.sourceforge.cobertura.coveragedata.LineData;
import net.sourceforge.cobertura.coveragedata.SwitchData;
import net.sourceforge.purrpackage.model.CoverageDataPair;
import net.sourceforge.purrpackage.model.CoverageSummaryView;
import net.sourceforge.purrpackage.model.LineDataPair;
import net.sourceforge.purrpackage.reporting.json.org.json.JSONObject;


public class SourceFileJsonFormatter extends JsonFormatter {

	public SourceFileJsonFormatter() {
		register( CoverageSummaryView.class, new CoverageSummaryViewJsonFormatterElement() );
		register(CoverageDataPair.class,
				new JsonFormatterElement<CoverageDataPair>() {

					@Override
					public JSONObject format(CoverageDataPair x,
							JsonFormatter utility) throws Exception {
						JSONObject result = new JSONObject();
						result.put("elementCounts", utility.format(x
								.getElementCounts()));
						result.put("branchCounts", utility.format(x
								.getBranchCounts()));
						result.put("lineCounts", utility.format(x
								.getLineCounts()));
						result.put("displayName", x.getDisplayName());
						result.put("orderingObject", x.getOrderingObject());
						result.put("name", x.getName());
						if (!(x instanceof LineDataPair)) {
							result.put("childKeys", x.getChildKeys());
							JSONObject children = new JSONObject();
							for (Object o : x.getChildKeys()) {
								children.put(String.valueOf(o), utility
										.format(x.getChild(o)));
							}
							result.put("children", children);
						}
						else {
							LineData ld = (LineData) x.getData();
							LineData dld = (LineData) x.getSamePackageData();
							result.put( "hits", ld.getHits() );
							result.put( "branchHits", hitArray(ld) );
							long diagHits = 0;
							Collection<Long> diagBranchHits = new ArrayList<Long>();
							if ( dld != null ) {
								diagHits = dld.getHits();
								diagBranchHits = hitArray( dld );
							}
							result.put( "samePackageHits", diagHits );
							result.put( "samePackageBranchHits", diagBranchHits );
						}

						return result;
					}

					private Collection<Long> hitArray(LineData ld) {
						ArrayList<Long> result = new ArrayList<Long>();
						if ( ld.hasBranch() ) {
							for ( int i = 0; i < ld.getConditionSize(); i++ ) {
								Object xcd = ld.getConditionData( i );
								if ( xcd instanceof SwitchData ) {
									SwitchData sd = (SwitchData) xcd;
									for( int j = 0; j < sd.getNumberOfValidBranches() - 1; j++ ) {
										result.add( sd.getHits( j ) );
									}
									result.add( sd.getDefaultHits() );
									}
								else {
									JumpData jd = (JumpData) xcd;
									result.add( jd.getTrueHits() );
									result.add( jd.getFalseHits() );
								}
							}
						}
						return result;
					}

				});
	}

}
